@@ -3,21 +3,24 @@ package Perl::Dist::Asset;
 # Convenience base class for Perl::Dist assets
 
 use strict;
-use Carp           'croak';
-use File::Spec     ();
-use File::ShareDir ();
-use URI::file      ();
-use Params::Util   qw{ _STRING _CODELIKE };
+use Carp             'croak';
+use File::Spec       ();
+use File::Spec::Unix ();
+use File::ShareDir   ();
+use URI::file        ();
+use Params::Util     qw{ _STRING _CODELIKE };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.29_02';
+	$VERSION = '0.90_01';
 }
 
 use Object::Tiny qw{
-	share
-	url
 	file
+	url
+	share
+	dist
+	cpan
 };
 
 
@@ -31,7 +34,7 @@ sub new {
 	my $self = shift->SUPER::new(@_);
 
 	# Map share to url
-	if ( $self->share ) {
+	if ( $self->share and ! $self->url ) {
 		my ($dist, $name) = split /\s+/, $self->share;
 		$self->trace("Finding $name in $dist... ");
 		my $file = File::Spec->rel2abs(
@@ -44,6 +47,18 @@ sub new {
 		$self->trace(" found\n");
 	}
 
+	# Map dist to url
+	if ( $self->dist and ! $self->url ) {
+		my $dist = $self->dist;
+		$self->trace("Using distribution path $dist\n");
+		my $one  = substr( $self->dist, 0, 1 );
+		my $two  = substr( $self->dist, 1, 1 );
+		my $path = File::Spec::Unix->catfile(
+			'authors', 'id', $one, "$one$two", $dist,
+		);
+		$self->{url} = URI->new_abs( $path, $self->cpan )->as_string;
+	}
+
 	# Check params
 	unless ( _STRING($self->url) ) {
 		croak("Missing or invalid url param");
