@@ -9,11 +9,12 @@ use base 'Perl::Dist::Asset';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.29_02';
+	$VERSION = '0.90_01';
 }
 
 use Object::Tiny qw{
 	name
+	force
 	license
 	unpack_to
 	install_to
@@ -49,6 +50,7 @@ sub new {
 	if ( $self->patch and ! _HASH($self->patch) ) {
 		croak("Invalid patch param");
 	}
+	$self->{force} = !! $self->force;
 
 	return $self;
 }
