@@ -6,7 +6,7 @@ use Params::Util qw{ _IDENTIFIER _STRING };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.29_02';
+	$VERSION = '0.90_01';
 }
 
 use Object::Tiny qw{
@@ -49,10 +49,10 @@ sub new {
 sub as_string {
 	my $self = shift;
 	return join( '; ',
-		"Name: "     . $self->name,
-		"Filename: " . $self->filename,
+		"Name: \""     . $self->name . "\"",
+		"Filename: \"" . $self->filename . "\"",
 		defined($self->working_dir)
-			? ("WorkingDir: " . $self->working_dir)
+			? ("WorkingDir: \"" . $self->working_dir . "\"")
 			: (),
 	);
 }
