@@ -9,10 +9,11 @@ use File::Path    ();
 use File::Remove  ();
 use t::lib::Test1 ();
 use t::lib::Test2 ();
+use t::lib::Test3 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.29_02';
+	$VERSION = '0.90_01';
 }
 
 
@@ -41,37 +42,45 @@ sub paths {
 	# Prepare the test directories
 	my $output_dir   = remake_path( "C:\\tmp\\sp\\output"   );
 	my $image_dir    = remake_path( "C:\\tmp\\sp\\image"    );
-	my $source_dir   = remake_path( "C:\\tmp\\sp\\source"   );
 	my $download_dir =   make_path( "C:\\tmp\\sp\\download" );
 	my $build_dir    = remake_path( "C:\\tmp\\sp\\build"    );
 	return (
 		output_dir   => $output_dir,
 		image_dir    => $image_dir,
-		source_dir   => $source_dir,
 		download_dir => $download_dir,
 		build_dir    => $build_dir,
 	);
 }
 
-sub cpan_uri {
-	my $path  = rel2abs( catdir( 't', 'data', 'cpan' ) );
+sub cpan {
+	if ( $ENV{TEST_PERLDIST_CPAN} ) {
+		return URI->new($ENV{TEST_PERLDIST_CPAN});
+	}
+	my $path = rel2abs( catdir( 't', 'data', 'cpan' ) );
 	Test::More::ok( -d $path, 'Found CPAN directory' );
-	Test::More::ok( -d catdir( $path, 'id' ), 'Found id subdirectory' );
+	Test::More::ok( -d catdir( $path, 'authors', 'id' ), 'Found id subdirectory' );
 	return URI::file->new($path . '\\');
 }
 
 sub new1 {
 	my $class = shift;
 	my @paths = $class->paths;
-	my $cpan_uri = $class->cpan_uri;
-	return t::lib::Test1->new( cpan_uri => $cpan_uri, @paths, @_ );
+	my $cpan  = $class->cpan;
+	return t::lib::Test1->new( cpan => $cpan, @paths, @_ );
 }
 
 sub new2 {
-	my $class    = shift;
-	my @paths    = $class->paths;
-	my $cpan_uri = $class->cpan_uri;
-	return t::lib::Test2->new( cpan_uri => $cpan_uri, @paths, @_ );
+	my $class = shift;
+	my @paths = $class->paths;
+	my $cpan  = $class->cpan;
+	return t::lib::Test2->new( cpan => $cpan, @paths, @_ );
+}
+
+sub new3 {
+	my $class = shift;
+	my @paths = $class->paths;
+	my $cpan  = $class->cpan;
+	return t::lib::Test3->new( cpan => $cpan, @paths, @_ );
 }
 
 1;
