@@ -1,11 +1,11 @@
 package t::lib::Test1;
 
 use strict;
-use base 'Perl::Dist';
+use base 'Perl::Dist::Inno';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.29_02';
+	$VERSION = '0.90_01';
 }
 
 
@@ -49,7 +49,7 @@ sub run {
 	return 1;
 }
 
-sub trace { 1 }
+sub trace { Test::More::diag($_[1]) }
 
 sub install_binary {
 	return shift->SUPER::install_binary( @_, trace => sub { 1 } );
